/* REXX * DISKIN ************************************************************/
/* Zweck...: Kopiert den Inhalt einer Digicam-Disk in ein Incoming-Verz.    */
/*           Dabei erhlt der Filename eine fortlaufende Nummer             */
/* Autor...: M. Dort (matthias.dort@epost.de)                               */
/*         : C. Beck (christian.beck11@epost.de)                            */
/* Date....: 8.7.2002                                                       */
vers = "1.6"                                             /* Programmversion */
/****************************************************************************/

/*****************************************************************************/
/* History:                                                                  */
/* V 1.0 - Original                                                          */
/* V 1.1 - Prfen, ob Quell UND Zielvereichnis bereit. Sonst Abbruch         */
/*	   Verwendung von verschiedenen Extensions                           */
/*	   Lschvorgang am Ende ohne Interaktion                             */
/* V 1.2 - Abfangen wenn fehlerhaft kopiert wird von Quell nach Ziellaufwerk */
/* V 1.3 - Ausgabe Erste letzte Nummer korrigiert /md                        */
/* V 1.4 - Vorbelegen der Variable "weiter" mit "J" zum automatischen Lschen*/
/*         Dateizhler macht fhrende 0000                                   */
/* V 1.5 - Ausgabe ber kopierte Dateien noch mal gendert.                  */
/*       - Funktion zum Auffllen mit 0 eingefhrt                           */
/* V 1.6 - Kommentare angepasst. Ausgaben Letzte Nummer, Es wurden insges..  */
/*         am Programende getauscht                                          */
/*****************************************************************************/

/*****************************************************************************/
/* ToDo:                                                                     */
/* momentan nix                                                              */
/*****************************************************************************/

/*****************************************************************************/
/* Ab hier bitte Variablen anpassen                                          */
/* --------------------------------                                          */
/* Quell-Laufwerk und Zielpfad (Incoming-Verzeichnis) definieren             */
/* Welche Dateiendungen sollen kopiert werden                                */
/*diskLW="e:\temp\diskin\diskette"         Becki-Test   */
/*incomingLW="e:\temp\diskin\platte"       Becki-Test   */

diskLW="g:\temp"                        /* Math-Test   */
incomingLW="g:\incom"                   /* Math-Test   */
/*****************************************************************************/

/* Hier werden die Extensions der Dateien eingetragen                        */
/* Wenn die eine oder andere hinzugefgt oder wegenommen wird, nicht         */
/* vergessen ext.0 entsprechend anzupassen !!!                               */
ext.0 = 3
ext.1 = "jpg"
ext.2 = "gif"
ext.3 = "mpeg"
/*****************************************************************************/

echo off
ARG parm .

/* Zur Laufwerksberprfung und SysFileDelete */
call rxfuncadd 'sysLoadFuncs', 'rexxutil', 'sysloadfuncs'
call sysloadfuncs

if (parm == "--HELP") | (parm == "-H") then do

/* Intro-Screen */

  say
  say "                        **********************"
  say "                        * - -  DISKIN  - - - *"
  say "                        *     ver. "vers "      *"              
  say "                        **********************"
  say
  say "     Kopiert den Inhalt einer Digicam-Disk in ein Importverzeichnis"
  say "     Dabei erhlt der Dateiname eine fortlaufende Nummer"
  say
  say "     Aufruf diskin"
  say
  say "     (c) M. Dort, matthias.dort@epost.de"
  say "     (c) C. Beck, christian.beck11@epost.de"
exit
end

else do

  say
    say "diskin [--help]"
   say

end

/* Jetzt geht das los */

/* Prfung, ob QuellLW bereit */
lw = substr(diskLW,1,2)
zeile = SysDriveInfo(lw)
if zeile == "" then
 do
   say 'Quelllaufwerk 'lw' ist nicht bereit.'
   say '(keine Diskette eingelegt ??)'
   exit
 end
else
 do
   parse var zeile  . . . name
   say 'Quelllaufwerk 'lw' hat die Bezeichnung: "'strip(name)'"'
 end

/* Prfung, ob ZielLW bereit */
lw = substr(incomingLW,1,2)
zeile = SysDriveInfo(lw)
if zeile == "" then
 do
   say 'Quelllaufwerk 'lw' ist nicht bereit.'
   say '(keine Diskette eingelegt ??)'
   exit
 end
else
 do
   parse var zeile  . . . name
   say 'Quelllaufwerk 'lw' hat die Bezeichnung: "'strip(name)'"'
 end

/* Temporre Files lschen */
"if exist "incomingLW"\*.tmp del "incomingLW"\*.tmp"

/* Zhlerdatei erstellen, falls sie nicht existiert */
 rc = lines(incomingLW"\zaehler")

if rc = 0 then do
  tmp = lineout(incomingLW"\zaehler","00000",1)
end

/* Zhlerindex einlesen */
x = stream(incomingLW'\zaehler','c','close') /* Damit Schreibzugriffe wieder mglich werden */
fileindex=linein(incomingLW"\zaehler")

/* Fileindex fr sptere Berechnung sichern */
fileindexalt=fileindex
/* Benutzer informieren       */
say "Erste neue Nummer ist "fileindexalt

/* Prfen, ob berhaupt Files mit der entsprechenden Extension auf Medium sind */
/* Wenn ja, mit dir die Namen in eine temp-Datei im incoming-Verz */
/* Der Schalter "/f" bewirkt, dass nur die Dateinamen incl. Pfad angezeigt werden */
do i = 1 to ext.0
  "if exist "diskLW"\*."ext.i "dir "diskLW"\*."ext.i" /f >> "incomingLW"\files.tmp"
end

/* Das eigentliche Prog. */
/* Tempdatei komplett auslesen, fr jede Zeile ein Cpoy-Befehl. */
/* Zhlindex eins hochzhlen */
do while lines(incomingLW"\files.tmp") > 0
  filename = linein(incomingLW"\files.tmp")
  l = length(filename)
  p = lastpos('.',filename)
  endung = substr(filename,p+1,l-p)
  filename_neu = fileindex"."endung

  "copy "filename incomingLW"\"filename_neu   
   if rc > 0 then
   do
     say 'Fehler beim Kopieren von 'filename' nach 'incomingLW'\'filename_neu
     say 'Returncode = 'rc
     say 'Prozedur wird beendet !' 
     exit
   end
   rc = sysfiledelete(filename)
   if rc > 0 then
   do
     say 'Originaldatei auf Quelldatentraeger ('filename')'
     say 'konnte nicht gelscht werden RC = 'rc
     say '   2              Fehler. Datei nicht gefunden '
     say '   3              Fehler. Pfad nicht gefunden '
     say '   5              Fehler. Zugriff verweigert '
     say '   26             Fehler. Kein DOS-Datentrger' 
     say '   32             Fehler. Konflikt beim gemeinsamen Zugriff '
     say '   36             Fehler. berlauf im Puffer fr gemeinsamen Zugriff '
     say '   87             Fehler. Ungltiger Parameter '
     say '   206            Fehler. Dateiname oder Dateierweiterung zu lang '
   end

   /* Zhler um eins erhhen */
  fileindex = fileindex + 1
  fileindex = auffuellen(fileindex)
end

/* Neuen Zhlerstand in erste Zeile zurckschreiben */
tmp = lineout(incomingLW"\"zaehler,fileindex,1)

/* Nur wenn wirklich was gemacht wurde, Benuzer ber letztes kopiertes File informieren */
if fileindex-fileindexalt \== 0 then do
  fileindex=fileindex-1
  fileindex = auffuellen(fileindex)
  say "Letzte neue Nummer ist "fileindex
  fileindex = fileindex+1
end  

/* Soviel wurde insgesamt kopiert     */
say "Es wurden insgesamt "fileindex-fileindexalt " Dateien kopiert."

/* Temporre Files lschen */
x = stream(incomingLW'\files.tmp','c','close') /* Damit Schreibzugriffe wieder mglich werden */
"if exist "incomingLW"\*.tmp del "incomingLW"\*.tmp" 

say "Quell-LW "diskLW" kann jetzt ganz gelscht werden."

/* Diskette lschen */
/* Die Sony-Mavica legt immer noch zu jeder Bilddatei eine versteckte Datei an, */
/* Deshalb vor dem Lschen atribute zurtcksetzten */

say diskLW " Lschen ? j/n (J)"
  pull weiter      /* vorbelegen */
  if (weiter = "J") | (weiter = "") then 
   do
    "if exist "diskLW"\*" attrib diskLw"\* -h -r -s"
    "if exist "diskLW"\*" del diskLw"\* /N" 
     say "Zu spt, nu is alles wech.."
   end

return 0

/* Funktion zum auffllen des Fileindex mit 0. Insgesamt immer 5-stellig */
/* Dient dem besseren Listing der Files */

auffuellen:
  arg variable
  /* Damit die Files geordnet fuer Dateibetrachter angeordnet werden */
  if (variable > 0) & (variable < 10) then variable = '0000'variable
  if (variable > 9) & (variable < 100) then variable = '000'variable
  if (variable > 99) & (variable < 1000) then variable = '00'variable
  if (variable > 999) & (variable < 10000) then variable = '0'variable
return variable